# -*- coding: utf-8 -*-
"""
models are data transfer objects or "light-weight" domain objects with no appreciable logic.
models are used to pass data between layers of the stack.

Conda modules importable from ``conda.models`` are

- ``conda._vendor``
- ``conda.common``
- ``conda.models``

"""
from __future__ import absolute_import, division, print_function
